package com.qmth.distributed.print.business.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.qmth.distributed.print.business.bean.dto.obe.CourseRequirementMatrixDto;
import com.qmth.distributed.print.business.bean.dto.report.ObeCourseRequirementDto;
import com.qmth.distributed.print.business.bean.dto.report.ObeSubRequirementsDto;
import com.qmth.distributed.print.business.bean.result.ObeCourseRequirementListResult;
import com.qmth.distributed.print.business.entity.ObeCourseRequirementReport;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 课程毕业要求报表 服务类
 * </p>
 *
 * @author wangliang
 * @since 2024-06-13
 */
public interface ObeCourseRequirementReportService extends IService<ObeCourseRequirementReport> {

    /**
     * 换算课程毕业达成度报表详情
     *
     * @param courseRequirementMatrixDtoList
     * @param obeCourseOutlineId
     * @param examId
     * @return
     */
    public Map<String, Object> matrixCourseReportInfo(List<CourseRequirementMatrixDto> courseRequirementMatrixDtoList,
                                                      Long obeCourseOutlineId, Long examId,
                                                      List<ObeCourseRequirementDto> obeCourseRequirementDtoList,
                                                      Map<Long, List<ObeSubRequirementsDto>> obeSubRequirementsDtoMap);

    /**
     * 换算课程毕业达成度报表
     *
     * @param obeCourseRequirementDtoList
     * @param obeSubRequirementsDtoMap
     * @return
     */
    public ObeCourseRequirementDto matrixCourseReport(List<ObeCourseRequirementDto> obeCourseRequirementDtoList,
                                                      Map<Long, List<ObeSubRequirementsDto>> obeSubRequirementsDtoMap);

    /**
     * 换算课程毕业达成度报表共用
     *
     * @param obeCourseRequirementDtoList
     * @param obeSubRequirementsDtoMap
     * @return
     */
    public List<ObeCourseRequirementDto> matrixCourseReportCommon(List<ObeCourseRequirementDto> obeCourseRequirementDtoList,
                                                                  Map<Long, List<ObeSubRequirementsDto>> obeSubRequirementsDtoMap);

    /**
     * 查找课程毕业达成度报表列表
     *
     * @param iPage
     * @param professionalId
     * @param cultureProgramName
     * @return
     */
    public IPage<ObeCourseRequirementListResult> obeCourseRequirementReportList(IPage<Map> iPage, Long professionalId, String cultureProgramName);

    /**
     * 根据培养方案删除报表
     *
     * @param cultureProgramId
     * @return
     */
    public boolean removeReport(Long cultureProgramId);

    /**
     * 根据培养方案查询报表
     *
     * @param cultureProgramId
     * @return
     */
    ObeCourseRequirementReport findByCultureProgramId(Long cultureProgramId);
}
